---
title: 指南
weight: 2
prev: /docs/getting-started
next: /docs/guide/organize-files
sidebar:
  open: true
---

探索以下各节以学习如何使用 Hextra 编写内容：

<!--more-->

{{< cards >}}
  {{< card link="organize-files" title="目录结构" icon="document-duplicate" >}}
  {{< card link="configuration" title="配置" icon="adjustments" >}}
  {{< card link="markdown" title="Markdown" icon="markdown" >}}
  {{< card link="syntax-highlighting" title="代码高亮" icon="sparkles" >}}
  {{< card link="latex" title="LaTeX 公式" icon="variable" >}}
  {{< card link="diagrams" title="图表" icon="chart-square-bar" >}}
  {{< card link="shortcodes" title="短代码" icon="template" >}}
{{< /cards >}}
